@@ -26,6 +26,7 @@ import pybtex.io
 from pybtex.core import Entry, Person
 from pybtex.database.input import ParserBase
 from pybtex.bibtex.utils import split_name_list
+from pybtex.exceptions import PybtexError
 from pybtex import textutils
 
 month_names = {
@@ -51,6 +52,8 @@ def normalize_whitespace(s, loc, toks):
 
 
 class Parser(ParserBase):
+    unicode_io = True
+
     def __init__(self, encoding=None, macros=month_names, person_fields=Person.valid_roles, **kwargs):
         ParserBase.__init__(self, encoding)
 
@@ -89,7 +92,7 @@ class Parser(ParserBase):
         #preamble
         preamble_body = bibtexGroup(value)
         preamble = at + CaselessLiteral('PREAMBLE').suppress() + preamble_body
-        preamble.setParseAction(self.process_preamble)
+        preamble.setParseAction(lambda toks: self.process_preamble(toks))
 
         #bibliography entry
         entry_header = at + Word(alphas).setParseAction(downcaseTokens)
@@ -99,14 +102,14 @@ class Parser(ParserBase):
         else:
             entry_body = bibtexGroup(entry_key + comma + Group(fields) + Optional(comma))
         entry = entry_header + entry_body
-        entry.setParseAction(self.process_entry)
+        entry.setParseAction(lambda toks: self.process_entry(toks))
 
         self.BibTeX_entry = string | preamble | entry
 
-    def process_preamble(self, s, loc, toks):
+    def process_preamble(self, toks):
         self.data.add_to_preamble(toks[0])
 
-    def process_entry(self, s, loc, toks):
+    def process_entry(self, toks):
         entry = Entry(toks[0].lower())
         fields = {}
         key = toks[1]
@@ -125,19 +128,22 @@ class Parser(ParserBase):
         self.data.add_entry(key, entry)
 
     def substitute_macro(self, s, loc, toks):
-        return self.macros[toks[0].lower()]
+        key = toks[0].lower()
+        try:
+            return self.macros[key]
+        except KeyError:
+            raise PybtexError('undefined macro %s' % key)
 
     def process_macro(self, s, loc, toks):
         self.macros[toks[0][0].lower()] = toks[0][1]
 
     def parse_stream(self, stream):
         self.unnamed_entry_counter = 1
-        s = pybtex.io.reader(stream, self.encoding).read()
 
         self.macros = dict(self.default_macros)
         try:
 #            entries = dict(entry[0][0] for entry in self.BibTeX_entry.scanString(s))
-            self.BibTeX_entry.searchString(s)
+            self.BibTeX_entry.searchString(stream.read())
         except ParseException, e:
             print "%s: syntax error:" % getattr(stream, 'name', '<NO FILE>')
             print e
