@@ -14,19 +14,48 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import pybtex.io
+from pybtex.bibtex.exceptions import BibTeXError
+from pybtex.bibtex.utils import scan_bibtex_string
 from pybtex.database.output import WriterBase
 
 file_extension = 'bib'
 
+
 class Writer(WriterBase):
     """Outputs BibTeX markup"""
 
+    unicode_io = True
+
     def quote(self, s):
-        return '"%s"' % s.replace('"', "''")
+        """
+        >>> w = Writer()
+        >>> print w.quote('The World')
+        "The World"
+        >>> print w.quote(r'The \emph{World}')
+        "The \emph{World}"
+        >>> print w.quote(r'The "World"')
+        {The "World"}
+        >>> try:
+        ...     print w.quote(r'The {World')
+        ... except BibTeXError, error:
+        ...     print error
+        String has unmatched braces: The {World
+        """
+
+        self.check_braces(s)
+        if '"' not in s:
+            return '"%s"' % s
+        else:
+            return '{%s}' % s
+
+    def check_braces(self, s):
+        end_brace_level = list(scan_bibtex_string(s))[-1][1]
+        if end_brace_level != 0:
+            raise BibTeXError('String has unmatched braces: %s' % s)
 
     def write_stream(self, bib_data, stream):
         def write_field(type, value):
-            f.write(',\n    %s = %s' % (type, self.quote(value)))
+            stream.write(u',\n    %s = %s' % (type, self.quote(value)))
         def format_name(person):
             def join(l):
                 return ' '.join([name for name in l if name])
@@ -47,20 +76,19 @@ class Writer(WriterBase):
         def write_persons(persons, role):
 #            persons = getattr(entry, role + 's')
             if persons:
-                write_field(role, ' and '.join([format_name(person) for person in persons]))
+                write_field(role, u' and '.join([format_name(person) for person in persons]))
         def write_preamble(preamble):
             if preamble:
-                f.write('@preamble{%s}\n\n' % self.quote(preamble))
+                stream.write(u'@preamble{%s}\n\n' % self.quote(preamble))
 
-        f = pybtex.io.writer(stream, self.encoding)
         write_preamble(bib_data.preamble())
         for key, entry in bib_data.entries.iteritems():
-            f.write('@%s' % entry.type)
-            f.write('{\n')
-            f.write('    %s' % key)
+            stream.write(u'@%s' % entry.type)
+            stream.write(u'{\n')
+            stream.write(u'    %s' % key)
 #            for role in ('author', 'editor'):
             for role, persons in entry.persons.iteritems():
                 write_persons(persons, role)
             for type, value in entry.fields.iteritems():
                 write_field(type, value)
-            f.write('\n}\n\n')
+            stream.write(u'\n}\n\n')
